# jupyter-require

Jupyter library and magic extension for managing linked JavaScript and CSS scripts and styles.


Package Install
---------------

**Prerequisites**
- [node](http://nodejs.org/)

```bash
npm install --save jupyter-require
```
